@@ -38,14 +38,14 @@ class HidTest(unittest.TestCase):
 
     def test_open_close(self):
         dev = self.get_device()
-        for i in xrange(0, 10):
+        for i in range(0, 10):
             dev.open()
             dev.close()
 
     def test_echo(self):
-        msg1 = 'hello world!'
-        msg2 = '            '
-        msg3 = ''
+        msg1 = b'hello world!'
+        msg2 = b'            '
+        msg3 = b''
         with self.get_device() as dev:
             self.assertEqual(dev.send_apdu(0x40, 0, 0, msg1), msg1)
             self.assertEqual(dev.send_apdu(0x40, 0, 0, msg2), msg2)
