@@ -29,7 +29,9 @@
 #APDU Instructions
 INS_ENROLL = 0x01
 INS_SIGN = 0x02
+INS_GET_VERSION = 0x03
 
 #APDU Response Codes
 APDU_OK = 0x9000
 APDU_USE_NOT_SATISFIED = 0x6985
+APDU_WRONG_DATA = 0x6a80
