@@ -95,7 +95,7 @@ def parse_args():
 def main():
     args = parse_args()
 
-    facet = text_type(args.facet, sys.stdin.encoding or sys.getdefaultencoding())
+    facet = text_type(args.facet)
     if args.infile:
         with open(args.infile, 'r') as f:
             data = f.read()
@@ -103,7 +103,7 @@ def main():
         if sys.stdin.isatty():
             sys.stderr.write('Enter RegistrationRequest JSON data...\n')
         data = sys.stdin.read()
-    params = json.loads(data, object_hook=u2str)
+    params = json.loads(data)
 
     if args.soft:
         from u2flib_host.soft import SoftU2FDevice
